Struct scoopit_api::requests::GetProfileRequest[][src]

pub struct GetProfileRequest {
    pub short_name: Option<String>,
    pub id: Option<String>,
    pub get_stats: bool,
    pub get_tags: bool,
    pub curated: Option<u32>,
    pub curable: Option<u32>,
    pub ncomments: Option<u32>,
    pub get_followed_topics: bool,
    pub get_curated_topics: bool,
    pub filter_curated_topics_by_creation_date_from: Option<u64>,
    pub filter_curated_topics_by_creation_date_to: Option<u64>,
    pub get_creator: bool,
}
Get the profile of a user.

Maps parameters of https://www.scoop.it/dev/api/1/urls#user

Documentation of each field comes from the page above. Default values documented are used only ff the field is not present (None), Default implementation for this struct may differ from Scoop.it defaults to avoid retrieving the world while only looking at the user profile.

Fields

short_name: Option<String>

string optional - the shortName of the user to lookup - defaults to the current user

id: Option<String>

long optional - the id of the user to lookup - defaults to the current user

get_stats: bool

bool optional - default to false. returns or not stats for each returned topic

get_tags: bool

bool optional - default to true. returns or not list of tags for each returned topic

curated: Option<u32>

int optional - default to 0, number of curated posts to retrieve for each topic present in user data

curable: Option<u32>

int optional - default to 0, number of curable posts to retrieve for each topic the current user is the curator (so it should not be specified if the “id” parameter is specified)

ncomments: Option<u32>

int optional - default to 0, the maximum number of comments to retrieve for each curated post found in each topic present in user data

get_followed_topics: bool

bool optional - default to true. returns or not list of followed topics

get_curated_topics: bool

bool optional - default to true. returns or not list of curated topics

filter_curated_topics_by_creation_date_from: Option<u64>

timestamp optional - default to 0 (unix epoch). Filter curated topics by creation date.

filter_curated_topics_by_creation_date_to: Option<u64>

timestamp optional - default to 2^63. Filter curated topics by creation date.

get_creator: bool

bool optional - default to true. returns or not creator of each returned topic