pub struct TestRequest { /* fields omitted */ }
Test authentication credentials.
https://www.scoop.it/dev/api/1/urls#test
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
The type returned by the Scoop.it API. Read more
The type returned by the client
Serialize this value into the given Serde serializer. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.