Struct scoopit_api::AccessToken[][src]

pub struct AccessToken { /* fields omitted */ }
An access token

Implementations

Creates a never expiring access token.

This token will never be renewed. If it comes to expire, all requests using it will fail.

Creates an access token.

If renew is provided the access will automatically renewed if needed.