pub struct AccessToken { /* fields omitted */ }
Creates a never expiring access token.
This token will never be renewed. If it comes to expire, all requests using it will fail.
Creates an access token.
If renew is provided the access will automatically renewed if needed.
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.